#
# spec file for package mercurial-extension-hg-git
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
%bcond_without test
%else
%bcond_with test
%endif

%if 0%{?suse_version} > 1600
# Tumbleweed
%define pythons python3
%else
%{?sle15_python_module_pythons}
%endif

Name:           mercurial-extension-hg-git
Version:        1.1.3
Release:        2.1
Summary:        Hg-Git Mercurial plugin
License:        GPL-2.0-only
Group:          Development/Tools/Version Control
URL:            http://foss.heptapod.net/mercurial/hg-git
Source0:        https://files.pythonhosted.org/packages/source/h/hg-git/hg_git-%{version}.tar.gz
Source90:       tests.blacklist
BuildRequires:  %{python_module dulwich >= 0.19.3}
BuildRequires:  %{pythons}
# python311-gpg is not available on Leap 15.6.
%if 0%{?suse_version} > 1600
BuildRequires:  %{python_module gpg}
%endif
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  mercurial
BuildRequires:  openssh-clients
BuildRequires:  python-rpm-macros
# On Leap, setuptools_scm does not explicitly require toml, but needs it to provide the correct version in dist-info.
%if 0%{?suse_version} < 1550
BuildRequires:  %{python_module toml}
%endif
BuildRequires:  unzip
Requires:       %{python_module dulwich >= 0.19.3}
Requires:       mercurial
Provides:       %{python_module hg-git = %{version}-%{release}}
Obsoletes:      %{python_module hg-git < %{version}-%{release}}
BuildArch:      noarch

%description
This plugin for Mercurial adds the ability to push and pull to/from a Git server repository from Hg. This means you can collaborate on Git based projects from Hg, or use a Git server as a collaboration point for a team with developers using both Git and Hg.

The Hg-Git plugin can convert commits/changesets losslessly from one system to another, so you can push via a Mercurial repository and another Hg client can pull it and their changeset node ids will be identical - Mercurial data does not get lost in translation. It is intended that Hg users may wish to use this to collaborate even if no Git users are involved in the project, and it may even provide some advantages if you’re using Bookmarks.

%prep
%setup -q -n hg_git-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{python_sitelib}

%check
%if %{with test}
make tests HGPYTHON=%{expand:%%__%{pythons}} TESTFLAGS="--blacklist=%{SOURCE90}"
%endif

%files
%doc README.rst
%license COPYING
%{python_sitelib}/*

%changelog
* Thu Sep 12 2024 Lukas Müller <expeehaa@outlook.com>
- Use existing python RPM macros instead of custom ones.
* Thu Jul 11 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 1.1.3.
  * Mark Dulwich 0.22.0 and 0.22.1 as unsupported. The compatibility hack didn't work in practice.
  * Mark Mercurial 6.8 as tested and supported.
- Changes from version 1.1.2:
  * Always advance draft phase, even if pulling from an explicit URL that isn't a named path.
  * Always save Git tags into the local, cached Git repository.
  * Add support for Dulwich 0.22.
* Tue Jun 18 2024 Lukas Müller <expeehaa@outlook.com>
- Build package with Python 3.11 on Leap 15.6.
* Fri Mar 22 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 1.1.1.
  * Fix pulling after marking the tip as obsolete.
  * Mark Mercurial 6.7 as supported.
- Changes from 1.1.0:
  * Remove some compatibility for now-unsupported versions of Dulwich.
- Changes from 1.1.0b1:
  * The gclear command is inherently dangerous, and has been
    replaced with a debug command instead.
  * The .hgsub and .gitmodules files are no longer retained when
    pushing to or pulling from Git, respectively. Instead, changes to
    each will be applied during the conversion.
  * Minor adjustments to categorisation of internal commands, and ensure
    that they all start with git-*.
  * Move configuration from the README file to contained within the
    extension, so that it is now self-documenting like Mercurial.
  * The -B/--bookmark flag for push will now restrict bookmarks
    by name rather than revision. (Please note that this is unsupported
    when the git.branch_bookmark_suffix configuration option is
    set.)
  * Pushing an unknown bookmark with the -B/--bookmark option now
    has the same effect as when pushing to a Mercurial repository, and
    will delete the remote Git branch.
  * You can now specify what to publish with the paths section.
  * Pushing and pulling from Git now triggers incoming, outgoing
    and changegroup hooks, along with the corresponding pre*
    hooks. In addition, the gitexport and gitimport hooks allow
    intercepting when commits are converted. As a result, you can now
    use the notify extension when interacting with Git repositories.
    (#402)
  * Git subrepositories will now be pushed as Git submodules.
- Changes from 1.0.4:
  * Address regression with Mercurial 6.4 and later where remote tags
    weren't updated on push.
* Thu Nov  9 2023 Andrei Dziahel <develop7@develop7.info>
- hg-git 1.0.3
  This is a minor release, focusing on bugs and compatibility.
  * Fix tests with Mercurial 6.5
  * Handle failures to save refs, such as when they use characters
    forbidden by the file system; this is most easily noticed on Windows
    and macOS. (#397)
  * Fix pulling annotated tags with `-r`/`--rev`.
- drop fix_mercurial_6.5_compatibility.patch
* Sat Oct  7 2023 Lukas Müller <expeehaa@outlook.com>
- Add BuildRequires that makes /usr/bin/ssh available in tests.
* Fri Aug 25 2023 Lukas Müller <expeehaa@outlook.com>
- Make tests actually run by adding "BuildRequires: python3-dulwich".
- Add unreleased upstream patch fix_mercurial_6.5_compatibility.patch.
* Mon Mar  6 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 1.0.2.
  * Fix --source/-s argument to transplant with Hg-Git enabled. (#392)
  * Fix cloning repositories using the old static HTTP support with Hg-Git enabled.
  * Handle pushing tags to Git that cannot be stored as references such as double-quotes on Windows. (#397)
  * Avoid converting unrelated refs on pull, such as Github PR-related refs. (#386)
  * Fix tests with GNU Grep 3.8 and later, by avoiding the egrep alias (#400)
  * Support reading remote refs even if packed.
  * Add support for Dulwich 0.21 and later.
  * Mark Mercurial 6.4 as supported and tested.
  * Address slowness when pulling large repositories, caused by writing unchanged references. (#401)
* Wed Feb  1 2023 Lukas Müller <expeehaa@outlook.com>
- BuildRequire python3-toml on Leap.
* Wed Feb  1 2023 Lukas Müller <expeehaa@outlook.com>
- Use pyproject.toml instead of setup.py for build and install.
- Add python3-setuptools_scm to determine the correct version of the package.
* Mon Dec 12 2022 Andrei Dziahel <develop7@develop7.info>
- Update to version 1.0.1
  This is a minor release, focusing on bugs and compatibility.
  * Ignore any ``GIT_SSH_COMMAND`` environment variable, rather than
    dying with an error. (#369)
  * Fix bug with unusual progress lines from Azure Repo (#391)
  * Fix incorrect use of localisation APIs (#387)
  * Fix pushing with Dulwich 0.2.49 or later.
  * Fix tests with Git 2.37.
  * Fix bug with tags or remote refs in the local Git repository that
    point to missing commits.
  * Mark Mercurial 6.2 and 6.3 as supported and tested.
* Mon Jul  4 2022 Manuel Jacob <me@manueljacob.de>
- Remove `BuildRequires: python3-dulwich >= 0.19.0`.
  The dependency is not available at build time on 15.3.
  We don’t need it at build time. The user has to provide
  the dependency from another repository at install time.
* Fri Jun 17 2022 Lukas Müller <expeehaa@outlook.com>
- Blacklist failing test.
* Mon May  2 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 1.0.0.
  Changelog: https://foss.heptapod.net/mercurial/hg-git/-/tags/1.0.0
- Remove "fix-tests-expecting-different-git-output.patch".
* Fri Mar 18 2022 Lukas Müller <expeehaa@outlook.com>
- Obsolete python3-hg-git as it is not the Factory package anymore
* Fri Mar 18 2022 Lukas Müller <expeehaa@outlook.com>
- Fix failing tests.
* Wed Feb  2 2022 Lukas Müller <expeehaa@outlook.com>
- Update to v0.10.4.
  * Fix compatibility with the mercurial_keyring extension. (#360)
  * Add missing test files to the source archive. (#375)
  * Fix tests with Git 2.34.
* Wed Nov 17 2021 Lukas Müller <expeehaa@outlook.com>
- Update to v0.10.3.
  * Add support for Mercurial 6.0.
* Mon Sep 20 2021 Lukas Müller <expeehaa@outlook.com>
- Rename package.
- Make spec file more similar to the one for tortoisehg.
- Set Group attribute to "Development/Tools/Version Control".
* Sat Jul 31 2021 Lukas Müller <expeehaa@outlook.com>
- Do not run tests on Leap to fix build failures.
* Sat Jul 31 2021 Lukas Müller <expeehaa@outlook.com>
- Update to v0.10.2.
  * Add support for Mercurial 5.9.
  * Fix the git.authors configuration option, broken in Python 3.
- Remove now unnecessary patch.
* Sun Jun 13 2021 Müller <expeehaa@outlook.com>
- Add python-hg-git-test-pull-after-rebase-fix.patch to fix failing test.
* Sun May 16 2021 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Update to v0.10.1
  + Add support for Mercurial 5.8.
  + Fix some documentation issues.
  + Don't overwrite annotated tags on push.
  + Fix an issue where pushing a repository without any bookmarks would
    push secret changesets.
* Sun Apr 18 2021 Müller <expeehaa@outlook.com>
- Create initial package using py2pack and hg-git v0.10.0.
